module Concerns
  module WinewooUserMixin
    extend ActiveSupport::Concern


    included do

      attr_accessor :current_device_id

      field :user_country, type: String
      field :user_city, type: String
      field :user_zip, type: String
      field :about, type: String
      field :viewed_interpro_ids, type: Array, default: []
      field :viewed_producer_ids, type: Array, default: []
      field :status, type: Symbol, default: :guest

      field :facebook_id, type: String
      field :twitter_id, type: String
      field :google_id, type: String
      field :linkedin_id, type: String

      field :reputation, type: Integer

      field :current_device_os, type: String

      ## Specific attributes
      field :name, type: String, default: "Winewooer"

      index interpro_ids: 1
      index producer_ids: 1

      embeds_many :history_entries, class_name: "HistoryEntry", inverse_of: :winewoo_user
      embeds_many :cellar_entries, class_name: "CellarEntry", inverse_of: :winewoo_user
      embeds_many :favorites, class_name: "Favorite", inverse_of: :winewoo_user
      embeds_many :winewoo_user_devices, class_name: "WinewooUserDevice", inverse_of: :winewoo_user

      has_many :user_comments, inverse_of: :winewoo_user, dependent: :destroy

      has_and_belongs_to_many :up_comments, class_name: "UserComment", inverse_of: :up_votes
      has_and_belongs_to_many :down_comments, class_name: "UserComment", inverse_of: :down_votes
    end


    def save_for_interpro(interpro)
      self.viewed_interpro_ids |= [interpro.id] if interpro
      self.save
    end


    def save_for_producer(producer)
      self.viewed_producer_ids |= [producer.id] if producer
      self.save
    end


    def add_wine_to_history(vintage, city, reco_id)
      self.history_entries.create(city: city,
                                  wine_id: vintage.wine.id,
                                  vintage_id: vintage.id,
                                  reco_id: reco_id)
      self.save
    end


    def guest?
      self.status == :guest
    end


    def authenticated?
      self.status == :authenticated
    end


    # Attempt to find a user by its email. If a record is found, send new
    # password instructions to it. If user is not found, returns a new user
    # with an email not found error.
    # Attributes must contain the user's email
    def self.send_reset_password_instructions(attributes={}, current_user_agent)
      recoverable = find_or_initialize_with_errors(reset_password_keys, attributes, :not_found)
      recoverable.current_device_os = current_user_agent.device_os
      recoverable.save
      recoverable.send_reset_password_instructions if recoverable.persisted?
      recoverable
    end
  end
end
