# Estate class represents the a domain owned by a producer.
# A producer can own several wine growing estates.
#
class Estate
  include Mongoid::Document
  include Mongoid::Timestamps
  include Concerns::Percentable
  include ActiveModel::ForbiddenAttributesProtection

  ## Personal informations
  field :address, type: String, default: ""
  field :zip_code, type: String, default: ""
  field :city, type: String, default: ""
  field :company, type: String, default: ""
  field :owner_lastname, type: String, default: ""
  field :owner_firstname, type: String, default: ""
  field :phone_number, type: String, default: ""
  field :fax_number, type: String, default: ""
  field :mobile_number, type: String, default: ""
  field :web_site, type: String, default: ""
  field :history, type: String, default: ""
  field :word, type: String, default: ""
  field :spoken_languages, type: Array
  field :markets, type: Array
  field :opening, type: String, default: ""
  field :contact_email, type: String

  embedded_in :producer, class_name: "User", inverse_of: :estates

  has_many :wines

  percented :company
  percented :owner_firstname
  percented :owner_lastname
  percented :address
  percented :zip_code
  percented :city
  percented :phone_number
  percented :history
  percented :word
  percented :opening
  percented :spoken_languages
  percented :markets

  def get_values_for(attr)
    (self.read_attribute(attr) || []).join(',')
  end

  def set_values_for(attr, values)
    self.write_attribute(attr, values.split(','))
  end
end
