class PictoElement
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::Search
  include ActiveModel::ForbiddenAttributesProtection

  field :key_name, :type => String
  field :name, :type => String, localize: true
  field :category, :type => Symbol
  field :android_mdpi_picto, :type => Moped::BSON::Binary
  field :android_hdpi_picto, :type => Moped::BSON::Binary
  field :android_xhdpi_picto, :type => Moped::BSON::Binary
  field :iphonex1_picto, :type => Moped::BSON::Binary
  field :iphonex2_picto, :type => Moped::BSON::Binary
  field :ipadx1_picto, :type => Moped::BSON::Binary
  field :ipadx2_picto, :type => Moped::BSON::Binary

  index({ key_name: 1 }, { unique: true })

  search_in :name

  validates_presence_of :key_name
  validates_uniqueness_of :key_name

  def self.method_missing(m, *args)
    if args.size == 1
      match = /_\w*_/.match m
      if match
        type = match.to_a[0]
        type.chop!.slice!(0)
        picto_hash = args[0].merge(category: type.parameterize.underscore.to_sym)
        PictoElement.create(picto_hash)
      end
    elsif args.size.zero?
      match = /_\w*/.match m
      if match
        type = match.to_a[0]
        type.slice!(0)
        PictoQuery
          .new
          .from_category(type.parameterize.underscore.to_sym)
          .to_a
      end
    end
  end
end
