require "mongoid_search"
## User class represents an interpro, a producer, an admin or a winewoo_user authenticated or guest.
#
# It is built using Devise and uses Pundit to manage roles and permissions.
# See documentations :
#   - https://github.com/plataformatec/devise
#
class User
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::Search
  include ActiveModel::ForbiddenAttributesProtection

  include Concerns::ProducerMixin
  include Concerns::InterproMixin
  include Concerns::AdminMixin
  include Concerns::WinewooUserMixin

  mount_uploader :avatar, AvatarUploader

  default_scope -> { order_by(name: :asc) }

  ## Database authenticatable
  field :email,              type: String
  field :encrypted_password, type: String

  ## Specific attributes
  field :name, type: String

  ## Recoverable
  field :reset_password_token,   type: String
  field :reset_password_sent_at, type: Time

  ## Rememberable
  field :remember_created_at, type: Time

  ## Trackable
  field :sign_in_count,      type: Integer, default: 0
  field :current_sign_in_at, type: Time
  field :last_sign_in_at,    type: Time
  field :current_sign_in_ip, type: String
  field :last_sign_in_ip,    type: String

  ## Confirmable
  # field :confirmation_token,   type: String
  # field :confirmed_at,         type: Time
  # field :confirmation_sent_at, type: Time
  # field :unconfirmed_email,    type: String # Only if using reconfirmable

  ## Lockable
  # field :failed_attempts, type: Integer, default: 0 # Only if lock strategy is :failed_attempts
  # field :unlock_token,    type: String # Only if unlock strategy is :email or :both
  # field :locked_at,       type: Time

  ## Personal informations
  field :updated, type: Boolean
  field :batched, type: Boolean

  field :user_roles, type: Array, default: [] # NEW

  ## Initialize search engine
  search_in :name, wines: :name

  ## Indexes
  # run 'rake db:mongoid:create_indexes' to create indexes
  index({ email: 1 }, { unique: true })
  index name: 1

  ## Validations
  validates_presence_of :encrypted_password
  validates_presence_of :email
  validates_uniqueness_of :email

  # List of notifications
  embeds_many :wine_notifications, cascade_callbacks: true

  has_many :wines, inverse_of: :producer, dependent: :destroy

  # Producer/Interpro <-> Pictures
  embeds_many :pictures, cascade_callbacks: true
  embeds_many :pictures, cascade_callbacks: true

  ## Methods
  def admin?
    (self.user_roles & [:admin, "admin"]).any?
  end

  def interpro?
    (self.user_roles & [:interpro, "interpro"]).any?
  end

  def producer?
    (self.user_roles & [:producer, "producer"]).any?
  end

  def winewoo_user?
    (self.user_roles & [:winewoo_user, "winewoo_user"]).any?
  end
end
