class UserComment
  include Mongoid::Document
  include Mongoid::Timestamps
  include ActiveModel::ForbiddenAttributesProtection

  after_save :set_average_rank_to_vintage
  after_destroy :set_average_rank_to_vintage

  default_scope -> { order_by(created_at: :desc) }

  field :text, type: String, default: ""
  field :rank, type: Float
  field :quality, type: Integer
  field :maturity, type: Integer
  field :view, type: Integer
  field :smell, type: Integer
  field :taste, type: Integer

  field :tasting_opportunities, type: Array, default: []
  field :tasting_flavors, type: Array, default: []
  field :tasting_food_entries, type: Array, default: []
  field :tasting_food_dishes, type: Array, default: []
  field :tasting_food_desserts, type: Array, default: []
  field :tasting_food_cheeses, type: Array, default: []

  field :reputation, type: Integer, default: 0

  field :reco_id, type: String

  validates_presence_of :vintage_id
  validates_presence_of :winewoo_user_id
  validates :winewoo_user_id, author: true

  belongs_to :winewoo_user, class_name: "User", inverse_of: :user_comments
  belongs_to :vintage
  belongs_to :wine

  has_and_belongs_to_many :up_votes, class_name: "UserComment", inverse_of: :up_comments
  has_and_belongs_to_many :down_votes, class_name: "UserComment", inverse_of: :down_comments


  class AuthorValidator < ActiveModel::EachValidator

    def validate_each(record, attribute, value)
      existing = nil
      if record.vintage
        existing = vintage.user_comments.find_by(winewoo_user_id: value)
        if existing
          record.errors[attribute] << options[:message] || 'has already posted a comment.'
        end
      end
      return existing ? false : true
    end
  end

  private

  def set_average_rank_to_vintage
    wine = Wine.find(self.wine_id)
    vintage = wine.vintages.find(self.vintage_id)
    vintage.update_average_rank!
  end
end
