class WinewooUserLog
  include Mongoid::Document
  include Mongoid::Timestamps
  include ActiveModel::ForbiddenAttributesProtection

  field :winewoo_user_id, type: Moped::BSON::ObjectId
  field :interpro_id, type: Moped::BSON::ObjectId
  field :from_interpro_app, type: Boolean
  field :producer_id, type: Moped::BSON::ObjectId
  field :wine_id, type: Moped::BSON::ObjectId
  field :vintage_id, type: Moped::BSON::ObjectId
  field :location, type: Array  # [lat,lng]
  field :action_date, type: DateTime
  field :app_name, type: String
  field :app_version, type: String
  field :action, type: String
  field :os, type: String
  field :params, type: Hash

  validates_presence_of :winewoo_user_id
  validates_presence_of :action_date
  validates_presence_of :app_name
  validates_presence_of :app_version
  validates_presence_of :action
  validates_inclusion_of :action,
    in: [ "app_launch",
          "search",
          "advanced_search",
          "wine_from_search",
          "wine_from_top_selection",
          "wine_from_advanced_search",
          "wine_from_favorites",
          "wine_from_history",
          "wine_from_cellar",
          "wine_from_pending_scan",
          "wine_from_camfind",
          "wine_from_scan",
          "wine_from_news",
          "update_cellar_wine",
          "cellar_wine",
          "uncellar_wine",
          "favorite_wine",
          "unfavorite_wine",
          "comment_wine",
          "facebook_share_wine",
          "twitter_share_wine",
          "pinterest_share_wine",
          "weibo_share_wine",
          "tencent_weibo_share_wine",
          "flickr_share_wine",
          "vimeo_share_wine",
          "email_share_wine",
          "sms_share_wine",
          "rank_wine"
  ]

  index({ winewoo_user_id: 1 }, { background: true })
  index({ interpro_id: 1 }, { background: true })
  index({ producer_id: 1 }, { background: true })
  index({ wine_id: 1 }, { background: true })
  index({ action: 1 }, { background: true })
  index({ os: 1 }, { background: true })
  index({ location: "2d" }, { min: -180, max: 180 })
end
