# encoding: utf-8
require "carrierwave"

class WineLabelUploader < CarrierWave::Uploader::Base
  include CarrierWave::RMagick

  # Include RMagick or MiniMagick support:
  # include CarrierWave::RMagick
  # include CarrierWave::MiniMagick

  # Include the Sprockets helpers for Rails 3.1+ asset pipeline compatibility:
  # include Sprockets::Helpers::RailsHelper
  # include Sprockets::Helpers::IsolatedHelper

  # Choose what kind of storage to use for this uploader:
  # storage :file
  # storage :fog

  # Override the directory where uploaded files will be stored.
  # This is a sensible default for uploaders that are meant to be mounted:
  def store_dir
    # uploads/#{model.class.to_s.underscore}/#{mounted_as}/#{model.id}
    # /opt/razad/:wine_id/:vintage_id
    begin
      vintage = model
      wine = vintage.wine
      "wine_labels/#{wine.id}/#{vintage.id}"
    rescue
      nil
    end
  end

  def move_to_cache
    false
  end

  # Provide a default URL as a default if there hasn't been a file uploaded:
  # def default_url
  #   # For Rails 3.1+ asset pipeline compatibility:
  #   # asset_path("fallback/" + [version_name, "default.png"].compact.join('_'))
  #
  #   "/images/fallback/" + [version_name, "default.png"].compact.join('_')
  # end

  # Process files as they are uploaded:
  # process :scale => [500, 500]
  #
  # def scale(width, height)
  #   # do something
  # end

  # Create different versions of your uploaded files:
  version :thumb do
    process :resize_to_limit => [250, 250]
  end
  version :medium do
    process :resize_to_limit => [700, 700]
  end
  version :small_thumb, :from_version => :thumb do
    process resize_to_limit: [100, 100]
  end

  # Add a white list of extensions which are allowed to be uploaded.
  # For images you might use something like this:
  def extension_white_list
    %w(jpg jpeg gif png)
  end

  # Override the filename of the uploaded files:
  # Avoid using model.id or version_name here, see uploader/store.rb for details.
  # def filename
  #   "something.jpg" if original_filename
  # end

  process :convert => 'png'

  def filename
    (super.chomp(File.extname(super)) + '.png').split(".png").first.gsub(".", "") + '.png' if original_filename
  end
end
