module WinewooCore
  class Configuration

    # This is a default variable used to test the behaviour of the gem.
    # Configure it in an initializer and you will be able to call
    # Winewoo.hello! to get it and see that the gem is imported and
    # can be configured.
    #
    attr_accessor :hello_sentence # optional

    # What is the provider of the authorize method ?
    # An authorizer must have an authorize method which will be called
    # by each use case on the current ressource.
    # For example the Back Office uses Pundit.
    attr_accessor :authorizer

    # REPOSITORIES FOR USE CASES
    attr_accessor :cellar_repo
    attr_accessor :comments_repo
    attr_accessor :criterions_repo
    attr_accessor :favorites_repo
    attr_accessor :history_repo
    attr_accessor :log_repo
    attr_accessor :users_repo
    attr_accessor :producers_repo
    attr_accessor :vintages_repo
    attr_accessor :wines_repo
    attr_accessor :winewoo_user_devices_repo
    attr_accessor :winewoo_user_logs_repo
    attr_accessor :winewoo_users_repo
    attr_accessor :feed_repo
    attr_accessor :global_wine_data_repo
    attr_accessor :award_repo
    # attr_accessor :interpro_criterions_repo
    # attr_accessor :interpro_producers_repo
    # attr_accessor :interpro_vintages_repo
    # attr_accessor :interpro_wines_repo
    # attr_accessor :interpro_winewoo_user_logs_repo
    # attr_accessor :interpro_winewoo_users_repo

    def initialize
      @hello_sentence = "Hello World !"
      @authorizer = Services::Authorizers::NullAuthorizer
      @cellar_repo = Repositories::Mongo::CellarMongoRepo
      @comments_repo = Repositories::Mongo::CommentsMongoRepo
      @criterions_repo = Repositories::Mongo::CriterionsMongoRepo
      @favorites_repo = Repositories::Mongo::FavoritesMongoRepo
      @history_repo = Repositories::Mongo::HistoryMongoRepo
      @log_repo = Repositories::Mongo::WinewooUserLogsMongoRepo
      @users_repo = Repositories::Mongo::UsersMongoRepo
      @producers_repo = Repositories::Mongo::ProducersMongoRepo
      @vintages_repo = Repositories::Mongo::VintagesMongoRepo
      @wines_repo = Repositories::Mongo::WinesMongoRepo
      @winewoo_user_devices_repo = Repositories::Mongo::WinewooUserDevicesMongoRepo
      @winewoo_user_logs_repo = Repositories::Mongo::WinewooUserLogsMongoRepo
      @winewoo_users_repo = Repositories::Mongo::WinewooUsersMongoRepo
      @feed_repo = Repositories::ElasticSearch::FeedElasticRepo
      @global_wine_data_repo = Repositories::Mongo::GlobalWineDataMongoRepo
      @award_repo = Repositories::Mongo::AwardMongoRepo
    end
  end
end
