module WinewooCore::Repositories::Mongo::Queries
  class ProducerQuery < UserQuery


    def initialize
      super User.where(user_roles: :producer)
    end


    def from_interpro(interpro_id)
      @relation = @relation
        .where(interpro_ids: interpro_id)

      block_given? ?
        @relation.each { |user| yield user } :
        self
    end


    def not_in(producer_ids)
      @relation = @relation
        .where(:_id.nin => producer_ids)

      block_given? ?
        @relation.each { |user| yield user } :
        self
    end


    def without_estates
      @relation = @relation
        .where(:estates.exists => false)

      block_given? ?
        @relation.each { |user| yield user } :
        self
    end


    def without_wines(interpro_id)
      producer_ids = WinewooCore::Repositories::Mongo::Queries::WineQuery
        .new
        .officials
        .from_interpro(interpro_id)
        .unscoped
        .distinct(:producer_id)

      @relation = @relation
        .where(:_id.nin => producer_ids)

      block_given? ?
        @relation.each { |user| yield user } :
        self
    end


    def with_auto_generated_estate
      @relation = @relation
        .where(:estates.elem_match =>
      { company: /Propriété : /i})

        block_given? ?
          @relation.each { |user| yield user } :
          self
    end


    def not_connected_yet
      @relation = @relation
        .where(:sign_in_count => 0)

      block_given? ?
        @relation.each { |user| yield user } :
        self
    end
  end
end
