module WinewooCore::Repositories::Mongo::Queries
  class WineQuery < WinewooQuery

    def initialize(relation = Wine)
      super relation
    end

    def from_producer(producer_id)
      @relation = @relation
        .where(producer_id: producer_id)

      block_given? ?
        @relation.each { |wine| yield wine } :
        self
    end

    def from_interpro(interpro_id)
      @relation = @relation
        .where(interpro_id: interpro_id)

      block_given? ?
        @relation.each { |wine| yield wine } :
        self
    end

    def with_vintage_id(vintage_id)
      @relation
        .where('vintages._id' => vintage_id)
        .first
    end

    def count_all_vintages
      @relation.all.inject(0) do |total, wine|
        total += wine.vintages.length
      end
    end

    def without_label
      @relation = @relation
        .where(:vintages.elem_match => { :wine_label.exists => false })

      block_given? ?
        @relation.each { |wine| yield wine } :
        self
    end

    def without_vintages
      @relation = @relation
        .where(:vintages.exists => false)

      block_given? ?
        @relation.each { |wine| yield wine } :
        self
    end

    def with_label
      @relation = @relation
        .where(:vintages.elem_match => { :wine_label.exists => true })

      block_given? ?
        @relation.each { |wine| yield wine } :
        self
    end

    def with_colors(colors)
      if colors
        @relation = @relation
          .any_in('color' => colors)

        block_given? ?
          @relation.each { |wine| yield wine } :
          self
      else
        self
      end
    end

    def with_appelation(appelation)
      if appelation
        @relation = @relation
          .where(:appelation.in => appelation)

        block_given? ?
          @relation.each { |wine| yield wine } :
          self
      else
        self
      end
    end

    def with_grapes(grapes)
      if grapes
        @relation = @relation
          .any_in('vintages.grapes.key' => grapes)

        block_given? ?
          @relation.each { |wine| yield wine } :
          self
      else
        self
      end
    end

    def with_storage_duration(durations)
      if durations
        @relation = @relation
          .any_in('vintages.storage_duration' => durations)

        block_given? ?
          @relation.each { |wine| yield wine } :
          self
      else
        self
      end
    end

    def with_tasting_opportunities(opportunities)
      if opportunities
        @relation = @relation
          .any_in('vintages.tasting_opportunities' => opportunities)

        block_given? ?
          @relation.each { |wine| yield wine } :
          self
      else
        self
      end
    end

    def percented_by(lower, higher)
      @relation = @relation
        .where(:computed_percent.gt => lower)
        .where(:computed_percent.lte => higher)

      block_given? ?
        @relation.each { |wine| yield wine } :
        self
    end

    def published
      @relation = @relation
        .where(:status => :published)

      block_given? ?
        @relation.each { |wine| yield wine } :
        self
    end

    def drafts
      @relation = @relation
        .where(:status.ne => :published)

      block_given? ?
        @relation.each { |wine| yield wine } :
        self
    end

    def officials
      @relation = @relation
        .where(unofficial: false)

      block_given? ?
        @relation.each { |wine| yield wine } :
        self
    end

    def unofficials
      @relation = @relation
        .where(unofficial: true)

      block_given? ?
        @relation.each { |wine| yield wine } :
        self
    end
  end
end
