module WinewooCore::Repositories::Mongo
  class VintagesMongoRepo

    def get(wine_id, vintage_id)
      return unless (wine_id && vintage_id)
      wine = Wine.find(wine_id)
      return unless wine
      wine.vintages.find(vintage_id)
    end


    def find(wine_id)
      return unless wine_id
      wine = Wine.find(wine_id)
      return unless wine
      wine.vintages
    end


    def create(current_user, wine_id, vintage_params)
      return unless wine_id
      wine = Wine.find(wine_id)
      return unless wine
      vintage = wine.vintages.build
      vintage.modified_by = current_user.id
      vintage.embedded_in = wine.id
      vintage.update_attributes(vintage_params)
      return vintage
    end


    def update(current_user, wine_id, vintage_id, vintage_params)
      return unless wine_id
      wine = Wine.find(wine_id)
      return unless wine
      vintage = wine.vintages.find(vintage_id)
      vintage.modified_by = current_user.id
      vintage.embedded_in = wine.id
      vintage.unofficial = false
      vintage.update_attributes(vintage_params)
      return vintage
    end


    def destroy(current_user, wine_id, vintage_id)
      return unless wine_id && vintage_id
      wine = Wine.find(wine_id)
      return unless wine
      vintage = wine.vintages.find(vintage_id)
      return unless vintage
      vintage.modified_by = current_user.id
      vintage.embedded_in = wine.id
      vintage.destroy
      return vintage
    end
  end
end
