module WinewooCore::Repositories::Mongo
  class WinesMongoRepo

    def get(wine_id)
      return unless wine_id
      Wine.find(wine_id)
    end


    def find(filters)
      WinewooCore::Services::Finders::Wines::WinesFinderBuilder
        .build(filters)
        .find
    end


    def create(current_user, producer_id, wine_params, vintage_params)
      return unless producer_id
      producer = User.find(producer_id)
      return unless producer
      wine = producer.wines.build
      wine.modified_by = current_user.id
      base_vintage = wine.vintages.build(vintage_params)
      base_vintage.save if wine.update_attributes(wine_params)
      return wine
    end


    def update(current_user, wine_id, wine_params)
      return unless wine_id
      wine = Wine.find(wine_id)
      return unless wine
      wine.modified_by = current_user.id
      wine.update_attributes(wine_params)
      return wine
    end


    def destroy(current_user, wine_id)
      return unless wine_id
      wine = Wine.find(wine_id)
      return unless wine
      wine.modified_by = current_user.id
      wine.destroy
      return wine
    end
  end
end
