module WinewooCore::Services::ElasticSearch
  class Parsers::NewsParser


    class << self

      def parse(raw_data, parse_error)
        if parse_error
          render_error_message
        else
          render_data(raw_data)
        end
      end


      private


      def render_data(raw_data)
        raw_data.map do |raw_entry|
          tweet = raw_entry["_source"]
          WinewooCore::Models::NewsEntry.new.tap do |entry|
            entry.type = tweet["type"] || :tweet
            entry.text = tweet["text"]
            entry.wine_id = tweet["wine_id"]
            entry.vintage_id = tweet["vintage_id"]
            entry.created_at = Time.parse(tweet["created_at"]).to_i
            entry.user = serialize_tweet_author(tweet["user"])
            entry.media = tweet["media"]
          end
        end
      end


      def render_error_message
        [
          WinewooCore::Models::NewsEntry.new.tap do |entry|
            entry.type = :tweet
            entry.text = "Suite à un problème serveur, nous sommes dans l'incapacité de délivrer nos services. Nous mettons tout en oeuvre pour y répondre dans les plus bref délais. Merci de votre compréhension."
            entry.created_at = Time.now.to_i
            entry.user = winewoo_author
          end
        ]
      end


      def serialize_tweet_media(medias)
        media = medias && medias.first
        media && { url: media["display_url"] }
      end


      def serialize_tweet_author(author)
        if author
          {
            twitter_id: author["id"],
            name: author["name"],
            profile_img: author["profile_image_url"],
            big_profile_img: author["profile_image_url"].gsub('normal', 'bigger')
          }
        else
          winewoo_author
        end
      end


      def winewoo_author
        {
          name: "winewoo",
          profile_img: "http://api.winewoo.com/images/default.png",
          big_profile_img: "http://api.winewoo.com/images/default.png"
        }
      end
    end
  end
end
