require 'elasticsearch'

module WinewooCore::Services::ElasticSearch
  class WinesServices

    def initialize
      @client = Elasticsearch::Client.new host: 'reco.kasual.biz:9200'
    end


    def fetch_wines(keywords, page, per_page)
      from = page * per_page
      size = per_page
      raw = @client.search index: "wines",
        body: request_body(keywords, from, size)

      Rails.logger.info "WINEWOO RAW #{raw}"

      Parsers::WinesParser.parse(raw["hits"]["hits"])
    end


    private

    def request_body(keywords, from, size)
      words = keywords.split(/( |-|')/).keep_if {|str| str.length > 2}.map {|str| "+#{str}*" }
      {
        query: { query_string: { fields:["name"], query: I18n.transliterate(words.join(" ")) } },
        sort: [ { "_score" => { order: "desc" }} ],
        from: from,
        size: size
      }
    end
  end
end
