module WinewooCore::UseCases
  class Wines::CreateWine < BaseUseCase

    def initialize(current_user, log_params=nil)
      super(WinewooCore.wines_repo.new, log_params)
      self.current_caller = current_user
    end


    def call(producer_id, wine_params, vintage_params)
      return unless authorize_wine_creation(&Proc.new)

      wine = create_wine_and_vintage(producer_id, wine_params, vintage_params)

      yield wine ?
        (wine.persisted? ?
         UseCaseResults.success(wine) :
         UseCaseResults.failure(wine.errors)) :
        UseCaseResults.not_found
    end


    private

    def authorize_wine_creation
      auth_params = authorization_params_for(:wine, :create?)
      res = self.authorizer.authorize_action(auth_params)
      yield UseCaseResults.unauthorized unless res
      return res
    end


    def create_wine_and_vintage(producer_id, wine_params, vintage_params)
      self.repo.create(self.current_caller,
                       producer_id,
                       wine_params,
                       vintage_params)
    end
  end
end
