module WinewooCore::UseCases
  class Wines::ListVintages < BaseUseCase

    def initialize(current_user, log_params=nil)
      super(WinewooCore.vintages_repo.new, log_params)
      self.current_caller = current_user
    end


    def call(wine_id)
      wine = WinewooCore.wines_repo.new.get(wine_id)
      return unless authorize_vintages_index(wine, &Proc.new)

      vintages = self.repo.find(wine_id)

      yield vintages ?
        UseCaseResults.found(vintages) :
        UseCaseResults.failure
    end


    private

    def authorize_vintages_index(wine)
      auth_params = authorization_params_for(:wine, :show?, wine)
      res = self.authorizer.authorize_action(auth_params)
      yield UseCaseResults.unauthorized unless res
      return res
    end
  end
end
