module WinewooCore::UseCases
  class Wines::ListWines < BaseUseCase

    def initialize(current_user, log_params=nil)
      super(WinewooCore.wines_repo.new, log_params)
      self.current_caller = current_user
    end


    def call(filters)
      return unless authorize_wines_index(&Proc.new)

      wines, action, total = self.repo.find(filters)
      log_search(action, filters.query, total)

      yield wines ?
        UseCaseResults.found(wines, total) :
        UseCaseResults.failure
    end


    private

    def authorize_wines_index
      auth_params = authorization_params_for(:wine, :index?)
      res = self.authorizer.authorize_action(auth_params)
      yield UseCaseResults.unauthorized unless res
      return res
    end


    def complete_log_params(action, search, nb_results)
      self.log_params.params = {
        "action" => action,
        "params" => { "search" => search, "results" => nb_results }
      }
      return self.log_params
    end


    def log_search(action, query, total)
      action && self.log_repo.create(complete_log_params(action, query, total))
    end
  end
end
