module WinewooCore::UseCases
  class Wines::RemoveVintage < BaseUseCase

    def initialize(current_user)
      super(WinewooCore.vintages_repo.new)
      self.current_caller = current_user
    end


    def call(wine_id, vintage_id)
      wine = WinewooCore.wines_repo.new.get(wine_id)
      return unless authorize_vintage_remove(wine, &Proc.new)

      vintage = self.repo.destroy(self.current_caller, wine_id, vintage_id)

      yield vintage ?
        UseCaseResults.success(vintage) :
        UseCaseResults.not_found
    end


    private

    def authorize_vintage_remove(wine)
      auth_params = authorization_params_for(:wine, :update?, wine)
      res = self.authorizer.authorize_action(auth_params)
      yield UseCaseResults.unauthorized unless res
      return res
    end
  end
end
