module WinewooCore::UseCases
  class Wines::RemoveWine < BaseUseCase

    def initialize(current_user)
      super(WinewooCore.wines_repo.new)
      self.current_caller = current_user
    end


    def call(wine_id)
      wine = self.repo.get(wine_id)
      return unless authorize_wine_remove(wine, &Proc.new)

      wine = self.repo.destroy(self.current_caller, wine_id)

      yield wine ?
        UseCaseResults.success(wine) :
        UseCaseResults.not_found
    end


    private

    def authorize_wine_remove(wine)
      auth_params = authorization_params_for(:wine, :remove?, wine)
      res = self.authorizer.authorize_action(auth_params)
      yield UseCaseResults.unauthorized unless res
      return res
    end
  end
end
