module WinewooCore::UseCases
  class Wines::UpdateAward < BaseUseCase

    def initialize(current_user)
      super(WinewooCore.award_repo.new)
      self.current_caller = current_user
    end


    def call(wine_id, vintage_id, awards_params)
      wine = WinewooCore.wines_repo.new.get(wine_id)
      return unless authorize_award_update(wine, &Proc.new)

      award = self.repo.update(wine_id, vintage_id, awards_params)

      yield award ?
        (award.errors.blank? ?
         UseCaseResults.success(award) :
         UseCaseResults.failure(award.errors)) :
        UseCaseResults.not_found
    end


    private

    def authorize_award_update(wine)
      auth_params = authorization_params_for(:wine, :update?, wine)
      res = self.authorizer.authorize_action(auth_params)
      yield UseCaseResults.unauthorized unless res
      return res
    end
  end
end
