module WinewooCore::UseCases
  class Wines::UpdateVintage < BaseUseCase

    def initialize(current_user)
      super(WinewooCore.vintages_repo.new)
      self.current_caller = current_user
    end


    def call(wine_id, vintage_id, vintage_params)
      wine = WinewooCore.wines_repo.new.get(wine_id)
      return unless authorize_wine_update(wine, &Proc.new)

      vintage = self.repo.update(self.current_caller, wine_id, vintage_id, wine_params)

      yield vintage ?
        (vintage.errors.blank? ?
         UseCaseResults.success(vintage) :
         UseCaseResults.failure(vintage.errors)) :
        UseCaseResults.not_found
    end


    private

    def authorize_vintage_creation(wine)
      auth_params = authorization_params_for(:wine, :update?, wine)
      res = self.authorizer.authorize_action(auth_params)
      yield UseCaseResults.unauthorized unless res
      return res
    end
  end
end
