module WinewooCore::UseCases
  class Wines::UpdateWine < BaseUseCase

    def initialize(current_user)
      super(WinewooCore.wines_repo.new)
      self.current_caller = current_user
    end


    def call(wine_id, wine_params)
      wine = self.repo.get(wine_id)
      return unless authorize_wine_update(wine, &Proc.new)

      wine = self.repo.update(self.current_caller, wine_id, wine_params)

      yield wine ?
        (wine.errors.blank? ?
         UseCaseResults.success(wine) :
         UseCaseResults.failure(wine.errors)) :
        UseCaseResults.not_found
    end


    private

    def authorize_vintage_creation(wine)
      auth_params = authorization_params_for(:wine, :update?, wine)
      res = self.authorizer.authorize_action(auth_params)
      yield UseCaseResults.unauthorized unless res
      return res
    end
  end
end
