module WinewooCore::UseCases
  class WinewooUser::Cellar::UpdateCellarEntry < BaseUseCase

    def initialize(log_params=nil)
      super(WinewooCore.cellar_repo.new, log_params)
    end


    def call(winewoo_user, entry_id, entry_params)
      entry = self.repo.update(winewoo_user, entry_id, entry_params)
      self.log_repo.create(complete_log_params(entry)) if entry && entry.errors.blank?

      yield entry ?
        (entry.errors.blank? ?
         UseCaseResults.success(entry) :
         UseCaseResults.failure(entry.errors)) :
        UseCaseResults.not_found
    end


    private

    def complete_log_params(entry)
      wine = WinewooCore.wines_repo.new.get(entry.wine_id)
      self.log_params.params = {
        "action" => "update_cellar_wine",
        "wine_id" => entry.wine_id,
        "vintage_id" => entry.vintage_id,
        "producer_id" => wine.official? ? wine.producer.id : nil,
        "params" => { "quantity" => entry.quantity }
      }
      return self.log_params
    end
  end
end
