module WinewooCore::UseCases
  class WinewooUser::Favorites::RemoveFavorite < BaseUseCase

    def initialize(log_params=nil)
      super(WinewooCore.favorites_repo.new, log_params)
    end


    def call(winewoo_user, favorite_id)
      favorite = self.repo.destroy(winewoo_user, favorite_id)
      self.log_repo.create(complete_log_params(favorite)) if favorite

      yield favorite ?
        UseCaseResults.success(favorite) :
        UseCaseResults.not_found
    end


    private

    def complete_log_params(favorite)
      wine = WinewooCore.wines_repo.new.get(favorite.wine_id)
      self.log_params.params = {
        "action" => "unfavorite_wine",
        "wine_id" => favorite.wine_id,
        "vintage_id" => favorite.vintage_id,
        "producer_id" => wine.official? ? wine.producer.id : nil
      }
      return self.log_params
    end
  end
end
